@@ -50,7 +50,6 @@ var searchData=
   ['sequenceinputstream',['SequenceInputStream',['../servicecom_1_1sun_1_1star_1_1io_1_1SequenceInputStream.html',1,'com::sun::star::io']]],
   ['sequenceoutputstream',['SequenceOutputStream',['../servicecom_1_1sun_1_1star_1_1io_1_1SequenceOutputStream.html',1,'com::sun::star::io']]],
   ['sequencetimecontainer',['SequenceTimeContainer',['../servicecom_1_1sun_1_1star_1_1animations_1_1SequenceTimeContainer.html',1,'com::sun::star::animations']]],
-  ['serialnumberadapter',['SerialNumberAdapter',['../servicecom_1_1sun_1_1star_1_1security_1_1SerialNumberAdapter.html',1,'com::sun::star::security']]],
   ['servicemanager',['ServiceManager',['../servicecom_1_1sun_1_1star_1_1lang_1_1ServiceManager.html',1,'com::sun::star::lang']]],
   ['servicenotfoundexception',['ServiceNotFoundException',['../exceptioncom_1_1sun_1_1star_1_1ucb_1_1ServiceNotFoundException.html',1,'com::sun::star::ucb']]],
   ['servicenotregisteredexception',['ServiceNotRegisteredException',['../exceptioncom_1_1sun_1_1star_1_1lang_1_1ServiceNotRegisteredException.html',1,'com::sun::star::lang']]],
@@ -140,7 +139,7 @@ var searchData=
   ['standarddiagramcreationparameters',['StandardDiagramCreationParameters',['../servicecom_1_1sun_1_1star_1_1chart2_1_1StandardDiagramCreationParameters.html',1,'com::sun::star::chart2']]],
   ['startmodule',['StartModule',['../servicecom_1_1sun_1_1star_1_1frame_1_1StartModule.html',1,'com::sun::star::frame']]],
   ['statechangeinprogressexception',['StateChangeInProgressException',['../exceptioncom_1_1sun_1_1star_1_1embed_1_1StateChangeInProgressException.html',1,'com::sun::star::embed']]],
-  ['statement',['Statement',['../servicecom_1_1sun_1_1star_1_1sdbcx_1_1Statement.html',1,'Statement'],['../servicecom_1_1sun_1_1star_1_1sdbc_1_1Statement.html',1,'Statement'],['../structcom_1_1sun_1_1star_1_1rdf_1_1Statement.html',1,'Statement']]],
+  ['statement',['Statement',['../structcom_1_1sun_1_1star_1_1rdf_1_1Statement.html',1,'Statement'],['../servicecom_1_1sun_1_1star_1_1sdbc_1_1Statement.html',1,'Statement'],['../servicecom_1_1sun_1_1star_1_1sdbcx_1_1Statement.html',1,'Statement']]],
   ['statusbarcontroller',['StatusbarController',['../servicecom_1_1sun_1_1star_1_1frame_1_1StatusbarController.html',1,'com::sun::star::frame']]],
   ['statusbarcontrollerfactory',['StatusbarControllerFactory',['../servicecom_1_1sun_1_1star_1_1frame_1_1StatusbarControllerFactory.html',1,'com::sun::star::frame']]],
   ['statusindicatorfactory',['StatusIndicatorFactory',['../servicecom_1_1sun_1_1star_1_1task_1_1StatusIndicatorFactory.html',1,'com::sun::star::task']]],
